// Load in the libraries
#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>

// Set the CE & CSN pins
#define CE_PIN   9
#define CSN_PIN 10

// Set gamepad joysticks
#define x_achses A0
#define y_achses A1
#define Abutton 2
#define lights_pin 4

// This is the address used to send/receive
const byte rxAddr[6] = "00001";

// Create a Radio
RF24 radio(CE_PIN, CSN_PIN); 

void setup() {
  
  // Start up the Serial connection
  while (!Serial);
  Serial.begin(9600);
  
  // Start the Radio!
  radio.begin();

  // Configure gamepad
  pinMode(x_achses, INPUT);
  pinMode(y_achses, INPUT);
  pinMode(Abutton, INPUT);
  pinMode(lights_pin, INPUT);
  
  // Power setting. Due to likelihood of close proximity of the devices, set as RF24_PA_MIN (RF24_PA_MAX is default)
  radio.setPALevel(RF24_PA_MIN); // RF24_PA_MIN, RF24_PA_LOW, RF24_PA_HIGH, RF24_PA_MAX
  
  // Slower data rate for better range
  radio.setDataRate( RF24_250KBPS ); // RF24_250KBPS, RF24_1MBPS, RF24_2MBPS
  
  // Number of retries and set tx/rx address
  radio.setRetries(15, 15);
  radio.openWritingPipe(rxAddr);

  // Stop listening, so we can send!
  radio.stopListening();
}

void loop() {
  //motor pwm
  int pwmMotor;
  int y_val = analogRead(y_achses);
  pwmMotor = map(y_val,0,700,127,-127);
  
  // Servo Angle
  int servoAngle;
  int x_val = analogRead(x_achses);
  servoAngle =  map(x_val,0,700,-127,127);
 
  int AbuttonVal = 0;
  AbuttonVal = digitalRead(Abutton);

  // lights
  int lights = 0;
  lights = digitalRead(lights_pin);
  
  // array for data
  char char_array[4] = {};

  char_array[0] = servoAngle;
  char_array[1] = pwmMotor;
  char_array[2] = AbuttonVal;
  char_array[3] = lights;

  // Ace, let's now send the message
  radio.write(&char_array, sizeof(char_array));
  
  // Let the ourside world know..
  Serial.print("Sent Message: ");
  Serial.println( servoAngle );
  Serial.println( y_val);
  Serial.println( AbuttonVal);
  Serial.println("********");
  
  // Wait a short while before sending the other one
  delay(100);
}
